% P value of the Null hypothesis that the balanced accuracy is not
% significantly above chance (i.e., the area under the pdf below 0.5).
%
% Usage:
%     b_p = bacc_p(C)
%
% Arguments:
%     C - 2x2 confusion matrix of classification outcomes. This matrix
%         needs to be of the form C = [a b; c d] where
%         <a> is the number of true positives
%         <b> is the number of false negatives
%         <c> is the number of false positives
%         <d> is the number of true negatives
%         In other words: rows are true classes, columns are estimated
%         classes.
% 
% Literature:
%     K.H. Brodersen, C.S. Ong, K.E. Stephan, J.M. Buhmann (2010).
%     The balanced accuracy and its posterior distribution. In: Proceedings
%     of the 20th International Conference on Pattern Recognition.

% Kay H. Brodersen, ETH Zurich, Switzerland
% http://people.inf.ethz.ch/bkay/
% $Id: bacc_p.m 8245 2010-10-22 12:57:51Z bkay $
% -------------------------------------------------------------------------
function b_p = bacc_p(C)
    
    % Get alphas and betas
    A1 = C(1,1) + 1;
    B1 = C(1,2) + 1;
    A2 = C(2,2) + 1;
    B2 = C(2,1) + 1;
    
    % Compute area under pdf below 0.5
    b_p = betaavgcdf(0.5,A1,B1,A2,B2);
    
end
